<?php

namespace Render;

/*
	This file contains functions to render various UI elements. The goal is to begin shifting elements in the game
	to HTMX/AJAX for more fluid gameplay.
*/

/**
 * Prepare content for final render. If the request is HTMX-based, will return just the content passed to it. Otherwise
 * it will render() onto $layout with some additional bits.
 */
function content(string $content, string $layout = 'layouts/primary'): string
{
	if (is_htmx()) return $content;
    return render($layout, ['content' => $content]);
}

function debug_db_info(): string {
	$total_time = round(microtime(true) - START, 4);
	$htmx = is_htmx() ? ' (htmx)' : '';
	return '<div id="debug-db-info" hx-swap-oob="true">'. $total_time . ' Seconds, ' . db()->count . ' Queries'.$htmx.'</div>';
}

function right_nav(): string
{
	if (user() === false) return '';

	// Flashy numbers if they're low
	$hp = (user()->currenthp <= (user()->maxhp / 5)) ? "<blink><span class=\"highlight\"><b>*" . user()->currenthp . "*</b></span></blink>" : user()->currenthp;
	$mp = (user()->currentmp <= (user()->maxmp / 5)) ? "<blink><span class=\"highlight\"><b>*" . user()->currentmp . "*</b></span></blink>" : user()->currentmp;

	$template = render('right_nav', ['hp' => $hp, 'mp' => $mp]);
	if (is_htmx()) $template = '<section id="right" hx-swap-oob="true">'.$template."</section>";
	return $template;
}

function left_nav(): string
{
	if (user() === false) return '';

	$template = render('left_nav');
	if (is_htmx()) $template = '<section id="left" hx-swap-oob="true">'.$template."</section>";
	return $template;
}

function babblebox(): string
{
	return render('babblebox', ['messages' => babblebox_messages()]);
}

function debug_query_log(): string
{
	$html = '<pre id="debug-query-log" hx-swap-oob="true">';
	foreach (db()->log as $record) {
		$query_string = str_replace(["\r\n", "\n", "\r"], ' ', $record[0]);
		$error_string = !empty($record[2]) ? '// '.$record[2] : '';
		$html .= '<div>['.round($record[1], 2)."s] {$query_string}{$error_string}</div>";
	}
	return $html . '</pre>';
}
